@@ -4,7 +4,7 @@
 #
 # Written by John Hughes <hughesj@umn.edu>.
 #
-# Last Modified 06/19/12
+# Last Modified 01/16/15
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/batchmeans package
@@ -15,16 +15,16 @@
 
 #' @import utils
 
-.onLoad = function(libname, pkgname)
+.onAttach = function(libname, pkgname)
 {
     # library.dynam("batchmeans", package = pkgname, lib.loc = libname)
     temp = packageDescription("batchmeans")
     msg = paste(temp$Package, ": ", temp$Title, "\n", "Version ", temp$Version,
                 " created on ", temp$Date, ".\n", sep = "")
     msg = paste(msg,
-"copyright (c) 2012, Murali Haran, Penn State University\n",
+"copyright (c) 2012-15, Murali Haran, Penn State University\n",
 "                    John Hughes, University of Minnesota\n", sep = "")
-    msg = paste(msg, 'For citation information, type citation("batchmeans").\n')
-    msg = paste(msg, 'Type help("batchmeans-package") to get started.\n')
+    msg = paste(msg, 'For citation information, type citation("batchmeans").\n', sep = "")
+    msg = paste(msg, 'Type help(package = batchmeans) to get started.\n', sep = "")
     packageStartupMessage(msg)
 }
